@@ -316,11 +316,13 @@ class WxApi(object):
     def upload_media(self, mtype, file_path=None, file_content=None):
         path = self.api_entry + 'media/upload?access_token=' \
             + self._access_token + '&type=' + mtype
+        suffix = {'image': '.jpg', 'voice': '.mp3',
+                  'video': 'mp4', 'thumb': 'jpg'}[mtype]
         if file_path:
-            tmp_path = tempfile.mkstemp(suffix='.jpg')[1]
+            tmp_path = tempfile.mkstemp(suffix=suffix)[1]
             shutil.copy(file_path, tmp_path)
         elif file_content:
-            tmp_path = tempfile.mkstemp(suffix='.jpg')[1]
+            tmp_path = tempfile.mkstemp(suffix=suffix)[1]
             f = open(tmp_path, 'wb')
             f.write(file_content)
             f.close()
@@ -399,11 +401,15 @@ class WxApi(object):
                 rsp, err = self.upload_media(
                     content_type,
                     file_content=obj.get(resource + '_content'))
+                if err:
+                    return None
             elif obj.get(resource + '_url'):
                 rs = requests.get(obj.get(resource + '_url'))
                 rsp, err = self.upload_media(
                     content_type,
                     file_content=rs.content)
+                if err:
+                    return None
             else:
                 return None
             return rsp['media_id']
